==> 0.0.2.tar.gz: ios/Classes/SwiftCheckoutPlugin.swift <==
import Flutter
import UIKit
import StandardCheckoutKit

public class SwiftCheckoutPlugin: NSObject, FlutterPlugin, StandardCheckoutDelegate {
    
    
   
    private var pendingResult: FlutterResult!
    
    var window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
            
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "checkout_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftCheckoutPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
        
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        switch call.method {
        case "payment":
            let options = call.arguments as! Dictionary<String, Any>
            
            self.pendingResult = result
            let params = options["requestParameters"] as! [String:Any]
            let secureKey = options["secureKey"] as? String ?? ""
            let requestParameters = RequestParameters(params)
            
            let controller : FlutterViewController = window.rootViewController as! FlutterViewController
            let standardCheckout = StandardCheckout(viewController: controller)
            standardCheckout.initPayment(requestParameters: requestParameters, standardCheckoutDelegate: self, secureKey: secureKey)
            
            break

        case "resync":
            print("inside resync")
            result(nil)
            return

        default:
            result(nil)
            return
        }
    }
    
    public func onSuccess(standardCheckoutResult: StandardCheckoutResult) {
        self.pendingResult(standardCheckoutResult.json as NSDictionary)
        return
    }
        
    public func onFail(response:[String:Any]) {
        let json = response
        self.pendingResult(json as NSDictionary)
        return
        

    }
    
}

==> 0.0.4.tar.gz: ios/Classes/SwiftCheckoutPlugin.swift <==
import Flutter
import UIKit
public class SwiftCheckoutPlugin: NSObject, FlutterPlugin, StandardCheckoutDelegate {
   
    private var pendingResult: FlutterResult!
    
    var window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
            
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "checkout_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftCheckoutPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
        
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        switch call.method {
        case "payment":
            let options = call.arguments as! Dictionary<String, Any>
            
            self.pendingResult = result
            let params = options["requestParameters"] as! [String:Any]
            let secureKey = options["secureKey"] as? String ?? ""
            let requestParameters = RequestParameters(params)
            
            let standardCheckoutViewController = StandardCheckoutViewController()
            standardCheckoutViewController.secureKey = secureKey
            standardCheckoutViewController.requestParameters = requestParameters
            standardCheckoutViewController.standardCheckoutDelegate = self
            print("Device==  \(requestParameters.device ?? "")")
            
            let controller : FlutterViewController = window.rootViewController as! FlutterViewController
            controller.present(standardCheckoutViewController, animated: true, completion: nil)
            break

        case "resync":
            print("inside resync")
            result(nil)
            return

        default:
            result(nil)
            return
        }
    }
    
    public func onSuccess(standardCheckoutResult: StandardCheckoutResult) {
        self.pendingResult(standardCheckoutResult.json as NSDictionary)
        return
    }
        
    public func onFail(response:[String:Any]) {
        let json = response
        self.pendingResult(json as NSDictionary)
        return
        

    }
}
